[Lldb-commits] [lldb] r122352 - /lldb/trunk/test/python_api/event/TestEvents.py

Johnny Chen johnny.chen at apple.com
Tue Dec 21 11:52:54 PST 2010


Author: johnny
Date: Tue Dec 21 13:52:54 2010
New Revision: 122352

URL: http://llvm.org/viewvc/llvm-project?rev=122352&view=rev
Log:
Rename the test methods to be more meaningful.

Modified:
    lldb/trunk/test/python_api/event/TestEvents.py

Modified: lldb/trunk/test/python_api/event/TestEvents.py
URL: http://llvm.org/viewvc/llvm-project/lldb/trunk/test/python_api/event/TestEvents.py?rev=122352&r1=122351&r2=122352&view=diff
==============================================================================
--- lldb/trunk/test/python_api/event/TestEvents.py (original)
+++ lldb/trunk/test/python_api/event/TestEvents.py Tue Dec 21 13:52:54 2010
@@ -14,16 +14,16 @@
 
     @unittest2.skipUnless(sys.platform.startswith("darwin"), "requires Darwin")
     @python_api_test
-    def test_with_dsym(self):
-        """Exercise SBEvent APIs."""
+    def test_wait_for_event_with_dsym(self):
+        """Exercise SBListener.WaitForEvent() APIs."""
         self.buildDsym()
-        self.do_events()
+        self.do_wait_for_event()
 
     @python_api_test
-    def test_with_dwarf(self):
-        """Exercise SBEvent APIs."""
+    def test_wait_for_event_with_dwarf(self):
+        """Exercise SBListener.WaitForEvent() APIs."""
         self.buildDwarf()
-        self.do_events()
+        self.do_wait_for_event()
 
     def setUp(self):
         # Call super's setUp().
@@ -31,8 +31,8 @@
         # Find the line number to of function 'c'.
         self.line = line_number('main.c', '// Find the line number of function "c" here.')
 
-    def do_events(self):
-        """Get the listener associated with the debugger and exercise some event APIs."""
+    def do_wait_for_event(self):
+        """Get the listener associated with the debugger and exercise WaitForEvent API."""
         exe = os.path.join(os.getcwd(), "a.out")
 
         # Create a target by the debugger.





More information about the lldb-commits mailing list